color

package
v0.0.0-...-d22ae78 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: AGPL-3.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Enabled bool

Enabled controls whether any ANSI escape codes are emitted. Automatically false when stdout is not a terminal or NO_COLOR is set.

var Full bool

Full indicates a capable terminal where dim and gray render correctly. False on Linux VGA console (TERM=linux), vt100, and similar basic terminals.

Functions

func Blue

func Blue(text string) string

func Bold

func Bold(text string) string

func BoldCyan

func BoldCyan(text string) string

func BoldGreen

func BoldGreen(text string) string

func BoldRed

func BoldRed(text string) string

func BoldYellow

func BoldYellow(text string) string

func Cyan

func Cyan(text string) string

func Dim

func Dim(text string) string

func Gray

func Gray(text string) string

func Green

func Green(text string) string

func Magenta

func Magenta(text string) string

func Red

func Red(text string) string

func Yellow

func Yellow(text string) string

Types

This section is empty.

Jump to