Documentation
¶
Index ¶
- Variables
- func Blue(text string) string
- func Bold(text string) string
- func BoldCyan(text string) string
- func BoldGreen(text string) string
- func BoldRed(text string) string
- func BoldYellow(text string) string
- func Cyan(text string) string
- func Dim(text string) string
- func Gray(text string) string
- func Green(text string) string
- func Magenta(text string) string
- func Red(text string) string
- func Yellow(text string) string
Constants ¶
This section is empty.
Variables ¶
var Enabled bool
Enabled controls whether any ANSI escape codes are emitted. Automatically false when stdout is not a terminal or NO_COLOR is set.
var Full bool
Full indicates a capable terminal where dim and gray render correctly. False on Linux VGA console (TERM=linux), vt100, and similar basic terminals.
Functions ¶
func BoldYellow ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.